@@ -1,9 +1,14 @@
+#!/usr/bin/env python3
+# Mikey Garcia, @gikeymarcia
+# https://github.com/gikeymarcia/pydymenu
+
+__author__ = "Mikey Garcia, @gikeymarcia"
 from pydymenu.fzf import FzfProtocol
 from pydymenu.fzf import fzf_func as fzf
 from pydymenu.rofi import RofiProtocol
 from pydymenu.rofi import rofi_func as rofi
 
 __author__ = "Mikey Garcia, @gikeymarcia"
-__version__ = "0.4.0"
+__version__ = "0.5.0"
 
 __all__ = ["fzf", "FzfProtocol", "rofi", "RofiProtocol"]
